@@ -34,6 +34,7 @@ class VirtualOperations(object):
         self.status_impl = None
         self.initialize_impl = None
         self.mount_specification_impl = None
+        self.source_size_impl = None
 
     def configure(self):
         def configure_decorator(configure_impl):
@@ -142,6 +143,16 @@ class VirtualOperations(object):
 
         return mount_specification_decorator
 
+    def source_size(self):
+        def source_size_decorator(source_size_impl):
+            if self.source_size_impl:
+                raise OperationAlreadyDefinedError(Op.VIRTUAL_SOURCE_SIZE)
+            self.source_size_impl = v.check_function(source_size_impl,
+                                                     Op.VIRTUAL_SOURCE_SIZE)
+            return source_size_impl
+
+        return source_size_decorator
+
     @staticmethod
     def _from_protobuf_single_subset_mount(single_subset_mount):
         return Mount(remote_environment=RemoteEnvironment.from_proto(
@@ -783,3 +794,57 @@ class VirtualOperations(object):
         ]
         virtual_mount_spec_response.return_value.mounts.extend(mounts_list)
         return virtual_mount_spec_response
+
+    def _internal_virtual_source_size(self, request):
+        """Virtual Source Size Wrapper.
+
+        Executed as part of several operations to get the virtual source size
+        of a virtual source
+
+        Run source_size operation for a virtual source.
+
+        Args:
+           request (VirtualSourceSizeRequest): Source Size Request arguments.
+
+        Returns:
+           VirtualSourceSizeResponse: A response containing the return value -
+           VirtualSourceSizeResult which has source size. In
+           case of errors, response object will contain PluginErrorResult.
+        """
+        # Reasoning for method imports are in this file's docstring.
+        from generated.definitions import VirtualSourceDefinition
+        from generated.definitions import RepositoryDefinition
+        from generated.definitions import SourceConfigDefinition
+
+        #
+        # While virtual.source_size() is not a required operation, this should
+        # not be called if it wasn't implemented.
+        #
+        if not self.source_size_impl:
+            raise OperationNotDefinedError(Op.VIRTUAL_SOURCE_SIZE)
+
+        virtual_source_definition = VirtualSourceDefinition.from_dict(
+            json.loads(request.virtual_source.parameters.json))
+        mounts = [
+            VirtualOperations._from_protobuf_single_subset_mount(m)
+            for m in request.virtual_source.mounts
+        ]
+        virtual_source = VirtualSource(guid=request.virtual_source.guid,
+                                       connection=RemoteConnection.from_proto(
+                                           request.virtual_source.connection),
+                                       parameters=virtual_source_definition,
+                                       mounts=mounts)
+        repository = RepositoryDefinition.from_dict(
+            json.loads(request.repository.parameters.json))
+        source_config = SourceConfigDefinition.from_dict(
+            json.loads(request.source_config.parameters.json))
+
+        source_size = self.source_size_impl(
+            virtual_source=virtual_source,
+            repository=repository,
+            source_config=source_config)
+
+        virtual_source_size_response = platform_pb2.VirtualSourceSizeResponse()
+        virtual_source_size_response.return_value.database_size = source_size
+
+        return virtual_source_size_response
